@@ -38,7 +38,6 @@
 #include <stdlib.h>
 
 #include <glib/gi18n.h>
-#include <gtksourceview/gtksourceiter.h>
 
 #include "gedit-settings.h"
 #include "gedit-document.h"
@@ -996,8 +995,8 @@ gedit_document_init (GeditDocument *doc)
 
 	doc->priv->encoding = gedit_encoding_get_utf8 ();
 
-	g_settings_get (doc->priv->editor_settings, GEDIT_SETTINGS_MAX_UNDO_ACTIONS,
-			"u", &undo_actions);
+	undo_actions = g_settings_get_int (doc->priv->editor_settings,
+					   GEDIT_SETTINGS_MAX_UNDO_ACTIONS);
 	bracket_matching = g_settings_get_boolean (doc->priv->editor_settings,
 						   GEDIT_SETTINGS_BRACKET_MATCHING);
 	search_hl = g_settings_get_boolean (doc->priv->editor_settings,
@@ -1203,7 +1202,7 @@ set_location (GeditDocument *doc,
  * gedit_document_get_location:
  * @doc: a #GeditDocument
  *
- * Returns: (allow-none): a copy of the internal #GFile
+ * Returns: (allow-none) (transfer full): a copy of the internal #GFile
  */
 GFile *
 gedit_document_get_location (GeditDocument *doc)
@@ -2146,7 +2145,7 @@ gedit_document_search_forward (GeditDocument     *doc,
 			       GtkTextIter       *match_end)
 {
 	GtkTextIter iter;
-	GtkSourceSearchFlags search_flags;
+	GtkTextSearchFlags search_flags;
 	gboolean found = FALSE;
 	GtkTextIter m_start;
 	GtkTextIter m_end;
@@ -2172,22 +2171,22 @@ gedit_document_search_forward (GeditDocument     *doc,
 	else
 		iter = *start;
 		
-	search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
+	search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
 
 	if (!GEDIT_SEARCH_IS_CASE_SENSITIVE (doc->priv->search_flags))
 	{
-		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
+		search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
 	}
 		
 	while (!found)
 	{
-		found = gtk_source_iter_forward_search (&iter,
-							doc->priv->search_text, 
-							search_flags,
-                        	                	&m_start, 
-                        	                	&m_end,
-                                	               	end);
-      	               	
+		found = gtk_text_iter_forward_search (&iter,
+		                                      doc->priv->search_text,
+		                                      search_flags,
+		                                      &m_start,
+		                                      &m_end,
+		                                      end);
+
 		if (found && GEDIT_SEARCH_IS_ENTIRE_WORD (doc->priv->search_flags))
 		{
 			found = gtk_text_iter_starts_word (&m_start) && 
@@ -2227,7 +2226,7 @@ gedit_document_search_backward (GeditDocument     *doc,
 				GtkTextIter       *match_end)
 {
 	GtkTextIter iter;
-	GtkSourceSearchFlags search_flags;
+	GtkTextSearchFlags search_flags;
 	gboolean found = FALSE;
 	GtkTextIter m_start;
 	GtkTextIter m_end;
@@ -2253,22 +2252,22 @@ gedit_document_search_backward (GeditDocument     *doc,
 	else
 		iter = *end;
 		
-	search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
+	search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
 
 	if (!GEDIT_SEARCH_IS_CASE_SENSITIVE (doc->priv->search_flags))
 	{
-		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
+		search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
 	}
 
 	while (!found)
 	{
-		found = gtk_source_iter_backward_search (&iter,
-							 doc->priv->search_text, 
-							 search_flags,
-                        	                	 &m_start, 
-                        	                	 &m_end,
-                                	               	 start);
-      	               	
+		found = gtk_text_iter_backward_search (&iter,
+		                                       doc->priv->search_text,
+		                                       search_flags,
+		                                       &m_start,
+		                                       &m_end,
+		                                       start);
+
 		if (found && GEDIT_SEARCH_IS_ENTIRE_WORD (doc->priv->search_flags))
 		{
 			found = gtk_text_iter_starts_word (&m_start) && 
@@ -2302,7 +2301,7 @@ gedit_document_replace_all (GeditDocument       *doc,
 	GtkTextIter iter;
 	GtkTextIter m_start;
 	GtkTextIter m_end;
-	GtkSourceSearchFlags search_flags = 0;
+	GtkTextSearchFlags search_flags = 0;
 	gboolean found = TRUE;
 	gint cont = 0;
 	gchar *search_text;
@@ -2327,11 +2326,11 @@ gedit_document_replace_all (GeditDocument       *doc,
 
 	gtk_text_buffer_get_start_iter (buffer, &iter);
 
-	search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
+	search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
 
 	if (!GEDIT_SEARCH_IS_CASE_SENSITIVE (flags))
 	{
-		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
+		search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
 	}
 
 	replace_text_len = strlen (replace_text);
@@ -2354,12 +2353,12 @@ gedit_document_replace_all (GeditDocument       *doc,
 
 	do
 	{
-		found = gtk_source_iter_forward_search (&iter,
-							search_text, 
-							search_flags,
-                        	                	&m_start, 
-                        	                	&m_end,
-                                	               	NULL);
+		found = gtk_text_iter_forward_search (&iter,
+		                                      search_text,
+		                                      search_flags,
+		                                      &m_start,
+		                                      &m_end,
+		                                      NULL);
 
 		if (found && GEDIT_SEARCH_IS_ENTIRE_WORD (flags))
 		{
@@ -2411,21 +2410,22 @@ gedit_document_replace_all (GeditDocument       *doc,
 }
 
 static void
-get_search_match_colors (GeditDocument *doc,
-			 gboolean      *foreground_set,
-			 GdkColor      *foreground,
-			 gboolean      *background_set,
-			 GdkColor      *background,
-			 gboolean      *line_background_set,
-			 GdkColor      *line_background,
-			 gboolean      *bold_set,
-			 gboolean      *bold,
-			 gboolean      *italic_set,
-			 gboolean      *italic,
-			 gboolean      *underline_set,
-			 gboolean      *underline,
-			 gboolean      *strikethrough_set,
-			 gboolean      *strikethrough)
+get_style_colors (GeditDocument *doc,
+                  const gchar   *style_name,
+                  gboolean      *foreground_set,
+                  GdkColor      *foreground,
+                  gboolean      *background_set,
+                  GdkColor      *background,
+                  gboolean      *line_background_set,
+                  GdkColor      *line_background,
+                  gboolean      *bold_set,
+                  gboolean      *bold,
+                  gboolean      *italic_set,
+                  gboolean      *italic,
+                  gboolean      *underline_set,
+                  gboolean      *underline,
+                  gboolean      *strikethrough_set,
+                  gboolean      *strikethrough)
 {
 	GtkSourceStyleScheme *style_scheme;
 	GtkSourceStyle *style;
@@ -2438,7 +2438,7 @@ get_search_match_colors (GeditDocument *doc,
 		goto fallback;
 
 	style = gtk_source_style_scheme_get_style (style_scheme,
-						   "search-match");
+						   style_name);
 	if (style == NULL)
 		goto fallback;
 
@@ -2504,9 +2504,9 @@ get_search_match_colors (GeditDocument *doc,
 }
 
 static void
-sync_found_tag (GeditDocument *doc,
-		GParamSpec    *pspec,
-		gpointer       data)
+sync_tag_style (GeditDocument *doc,
+                GtkTextTag    *tag,
+                const gchar   *style_name)
 {
 	GdkColor fg;
 	GdkColor bg;
@@ -2525,30 +2525,39 @@ sync_found_tag (GeditDocument *doc,
 
 	gedit_debug (DEBUG_DOCUMENT);
 
-	g_return_if_fail (GTK_TEXT_TAG (doc->priv->found_tag));
+	g_return_if_fail (tag != NULL);
 
-	get_search_match_colors (doc,
-				 &fg_set, &fg,
-				 &bg_set, &bg,
-				 &line_bg_set, &line_bg,
-				 &bold_set, &bold,
-				 &italic_set, &italic,
-				 &underline_set, &underline,
-				 &strikethrough_set, &strikethrough);
+	get_style_colors (doc,
+	                  style_name,
+	                  &fg_set, &fg,
+	                  &bg_set, &bg,
+	                  &line_bg_set, &line_bg,
+	                  &bold_set, &bold,
+	                  &italic_set, &italic,
+	                  &underline_set, &underline,
+	                  &strikethrough_set, &strikethrough);
 
-	g_object_freeze_notify (G_OBJECT (doc->priv->found_tag));
+	g_object_freeze_notify (G_OBJECT (tag));
 
-	g_object_set (doc->priv->found_tag,
-		      "foreground-gdk", fg_set ? &fg : NULL,
-		      "background-gdk", bg_set ? &bg : NULL,
-		      "paragraph-background-gdk", line_bg_set ? &line_bg : NULL,
-		      "weight", bold_set && bold ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL,
-		      "style", italic_set && italic ? PANGO_STYLE_ITALIC : PANGO_STYLE_NORMAL,
-		      "underline", underline_set && underline ? PANGO_UNDERLINE_SINGLE : PANGO_UNDERLINE_NONE,
-		      "strikethrough", strikethrough_set && strikethrough,
-		      NULL);
+	g_object_set (tag,
+	              "foreground-gdk", fg_set ? &fg : NULL,
+	              "background-gdk", bg_set ? &bg : NULL,
+	              "paragraph-background-gdk", line_bg_set ? &line_bg : NULL,
+	              "weight", bold_set && bold ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL,
+	              "style", italic_set && italic ? PANGO_STYLE_ITALIC : PANGO_STYLE_NORMAL,
+	              "underline", underline_set && underline ? PANGO_UNDERLINE_SINGLE : PANGO_UNDERLINE_NONE,
+	              "strikethrough", strikethrough_set && strikethrough,
+	              NULL);
 
-	g_object_thaw_notify (G_OBJECT (doc->priv->found_tag));
+	g_object_thaw_notify (G_OBJECT (tag));
+}
+
+static void
+sync_found_tag (GeditDocument *doc,
+		GParamSpec    *pspec,
+		gpointer       data)
+{
+	sync_tag_style (doc, doc->priv->found_tag, "search-match");
 }
 
 static void
@@ -2570,8 +2579,8 @@ search_region (GeditDocument *doc,
 {
 	GtkTextIter iter;
 	GtkTextIter m_start;
-	GtkTextIter m_end;	
-	GtkSourceSearchFlags search_flags = 0;
+	GtkTextIter m_end;
+	GtkTextSearchFlags search_flags = 0;
 	gboolean found = TRUE;
 
 	GtkTextBuffer *buffer;	
@@ -2635,11 +2644,11 @@ search_region (GeditDocument *doc,
 
 	iter = *start;
 		
-	search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
+	search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
 
 	if (!GEDIT_SEARCH_IS_CASE_SENSITIVE (doc->priv->search_flags))
 	{
-		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
+		search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
 	}
 	
 	do
@@ -2647,13 +2656,13 @@ search_region (GeditDocument *doc,
 		if ((end != NULL) && gtk_text_iter_is_end (end))
 			end = NULL;
 			
-		found = gtk_source_iter_forward_search (&iter,
-							doc->priv->search_text, 
-							search_flags,
-                        	                	&m_start, 
-                        	                	&m_end,
-                                	               	end);
-				
+		found = gtk_text_iter_forward_search (&iter,
+		                                      doc->priv->search_text,
+		                                      search_flags,
+		                                      &m_start,
+		                                      &m_end,
+		                                      end);
+
 		iter = m_end;
 						      	               	
 		if (found && GEDIT_SEARCH_IS_ENTIRE_WORD (doc->priv->search_flags))
@@ -2788,6 +2797,12 @@ gedit_document_set_language (GeditDocument     *doc,
 	set_language (doc, lang, TRUE);
 }
 
+/**
+ * gedit_document_get_language:
+ * @doc:
+ *
+ * Return value: (transfer none):
+ */
 GtkSourceLanguage *
 gedit_document_get_language (GeditDocument *doc)
 {
@@ -2929,7 +2944,6 @@ gedit_document_get_metadata (GeditDocument *doc,
 			     const gchar   *key)
 {
 	gchar *value = NULL;
-	gchar *uri;
 
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
 	g_return_val_if_fail (key != NULL, NULL);
@@ -3085,4 +3099,4 @@ gedit_document_set_metadata (GeditDocument *doc,
 }
 #endif
 
-/* ex:ts=8:noet: */
+/* ex:set ts=8 noet: */
