@@ -405,7 +405,7 @@ set_cursor_according_to_state (GtkTextView   *view,
 		if (left_window != NULL)
 			gdk_window_set_cursor (left_window, cursor);
 
-		gdk_cursor_unref (cursor);
+		g_object_unref (cursor);
 	}
 	else
 	{
@@ -418,7 +418,7 @@ set_cursor_according_to_state (GtkTextView   *view,
 		if (left_window != NULL)
 			gdk_window_set_cursor (left_window, NULL);
 
-		gdk_cursor_unref (cursor);
+		g_object_unref (cursor);
 	}
 }
 
@@ -960,7 +960,6 @@ document_loaded (GeditDocument *document,
 {
 	GtkWidget *emsg;
 	GFile *location;
-	const GeditEncoding *encoding;
 
 	g_return_if_fail ((tab->priv->state == GEDIT_TAB_STATE_LOADING) ||
 			  (tab->priv->state == GEDIT_TAB_STATE_REVERTING));
@@ -981,6 +980,8 @@ document_loaded (GeditDocument *document,
 	if (error != NULL &&
 	    (error->domain != GEDIT_DOCUMENT_ERROR || error->code != GEDIT_DOCUMENT_ERROR_CONVERSION_FALLBACK))
 	{
+		const GeditEncoding *encoding;
+
 		if (tab->priv->state == GEDIT_TAB_STATE_LOADING)
 			gedit_tab_set_state (tab, GEDIT_TAB_STATE_LOADING_ERROR);
 		else
@@ -2946,4 +2947,4 @@ _gedit_tab_get_view_frame (GeditTab *tab)
 	return GTK_WIDGET (tab->priv->frame);
 }
 
-/* ex:ts=8:noet: */
+/* ex:set ts=8 noet: */
